# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: msg_comm_request.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import msg_comm_cust_pb2 as msg__comm__cust__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='msg_comm_request.proto',
  package='MsgCommRequest',
  syntax='proto3',
  serialized_options=b'\n\034com.kaisaglobal.proto.common\200\001\000\210\001\001\220\001\000',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x16msg_comm_request.proto\x12\x0eMsgCommRequest\x1a\x13msg_comm_cust.proto\"v\n\x07ReqHead\x12\'\n\x08\x63ustHead\x18\x01 \x01(\x0b\x32\x15.MsgCommCust.CustHead\x12\r\n\x05reqId\x18\x02 \x01(\r\x12\x0b\n\x03mod\x18\x03 \x01(\r\x12\x0b\n\x03\x63md\x18\x04 \x01(\r\x12\x0b\n\x03len\x18\x05 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\x0c\x42\'\n\x1c\x63om.kaisaglobal.proto.common\x80\x01\x00\x88\x01\x01\x90\x01\x00\x62\x06proto3'
  ,
  dependencies=[msg__comm__cust__pb2.DESCRIPTOR,])




_REQHEAD = _descriptor.Descriptor(
  name='ReqHead',
  full_name='MsgCommRequest.ReqHead',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='custHead', full_name='MsgCommRequest.ReqHead.custHead', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reqId', full_name='MsgCommRequest.ReqHead.reqId', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mod', full_name='MsgCommRequest.ReqHead.mod', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cmd', full_name='MsgCommRequest.ReqHead.cmd', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='len', full_name='MsgCommRequest.ReqHead.len', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='MsgCommRequest.ReqHead.data', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=63,
  serialized_end=181,
)

_REQHEAD.fields_by_name['custHead'].message_type = msg__comm__cust__pb2._CUSTHEAD
DESCRIPTOR.message_types_by_name['ReqHead'] = _REQHEAD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ReqHead = _reflection.GeneratedProtocolMessageType('ReqHead', (_message.Message,), {
  'DESCRIPTOR' : _REQHEAD,
  '__module__' : 'msg_comm_request_pb2'
  # @@protoc_insertion_point(class_scope:MsgCommRequest.ReqHead)
  })
_sym_db.RegisterMessage(ReqHead)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
