# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: msg_comm_cust.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='msg_comm_cust.proto',
  package='MsgCommCust',
  syntax='proto3',
  serialized_options=b'\n\034com.kaisaglobal.proto.common\200\001\000\210\001\001\220\001\000',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x13msg_comm_cust.proto\x12\x0bMsgCommCust\"e\n\x08\x43ustHead\x12\x10\n\x08packFlag\x18\x01 \x01(\r\x12\x11\n\tiCompress\x18\x02 \x01(\r\x12\x10\n\x08iVersion\x18\x03 \x01(\r\x12\x10\n\x08iReserve\x18\x04 \x01(\r\x12\x10\n\x08iCheckId\x18\x05 \x01(\rB\'\n\x1c\x63om.kaisaglobal.proto.common\x80\x01\x00\x88\x01\x01\x90\x01\x00\x62\x06proto3'
)




_CUSTHEAD = _descriptor.Descriptor(
  name='CustHead',
  full_name='MsgCommCust.CustHead',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='packFlag', full_name='MsgCommCust.CustHead.packFlag', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='iCompress', full_name='MsgCommCust.CustHead.iCompress', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='iVersion', full_name='MsgCommCust.CustHead.iVersion', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='iReserve', full_name='MsgCommCust.CustHead.iReserve', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='iCheckId', full_name='MsgCommCust.CustHead.iCheckId', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=36,
  serialized_end=137,
)

DESCRIPTOR.message_types_by_name['CustHead'] = _CUSTHEAD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CustHead = _reflection.GeneratedProtocolMessageType('CustHead', (_message.Message,), {
  'DESCRIPTOR' : _CUSTHEAD,
  '__module__' : 'msg_comm_cust_pb2'
  # @@protoc_insertion_point(class_scope:MsgCommCust.CustHead)
  })
_sym_db.RegisterMessage(CustHead)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
