# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stock_real.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
import stock_comm_pb2 as stock__comm__pb2
import msg_comm_cust_pb2 as msg__comm__cust__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='stock_real.proto',
  package='Stock',
  syntax='proto3',
  serialized_options=b'\n#com.kaisaglobal.proto.stock.release\200\001\000\210\001\001\220\001\000',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x10stock_real.proto\x12\x05Stock\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x10stock_comm.proto\x1a\x13msg_comm_cust.proto\"<\n\x04Rule\x12$\n\nstockCodes\x18\x01 \x03(\x0b\x32\x10.Stock.StockCode\x12\x0e\n\x06\x66ields\x18\x02 \x03(\t\"\x8c\x01\n\tStockCode\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12#\n\x06market\x18\x02 \x01(\x0e\x32\x13.StockCommon.Market\x12\'\n\x08language\x18\x03 \x01(\x0e\x32\x15.StockCommon.Language\x12#\n\x05types\x18\x04 \x03(\x0e\x32\x14.StockCommon.SubType\"\x84\x04\n\x05Quote\x12\x0e\n\x06market\x18\x01 \x01(\r\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0b\n\x03now\x18\x03 \x01(\x01\x12\x0c\n\x04open\x18\x04 \x01(\x01\x12\x0c\n\x04high\x18\x05 \x01(\x01\x12\x0b\n\x03low\x18\x06 \x01(\x01\x12\x12\n\nlast_close\x18\x07 \x01(\x01\x12\x0e\n\x06volume\x18\x08 \x01(\x04\x12\x0e\n\x06\x61mount\x18\t \x01(\x01\x12\x13\n\x0bupdate_flag\x18\n \x03(\r\x12.\n\nquote_time\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\trecv_time\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12$\n\ngrey_quote\x18\r \x01(\x0b\x32\x10.Stock.GreyQuote\x12\x15\n\rquantityRatio\x18\x0e \x01(\x01\x12\r\n\x05\x63lose\x18\x0f \x01(\x01\x12\x1f\n\x07tick_vi\x18\x10 \x01(\x0e\x32\x0e.Stock.Tick_VI\x12\x16\n\x0etrading_status\x18\x11 \x01(\t\x12\x10\n\x08modifier\x18\x12 \x01(\t\x12\x14\n\x0cpre5MinPrice\x18\x13 \x01(\x01\x12\x11\n\touterDisk\x18\x14 \x01(\x01\x12\x11\n\tinnerDisk\x18\x15 \x01(\x01\x12\x15\n\rnasdaq_volume\x18\x16 \x01(\x01\x12\x15\n\rnasdaq_amount\x18\x17 \x01(\x01\"d\n\tGreyQuote\x12\x17\n\x0f\x63ur_trade_count\x18\x01 \x01(\r\x12\x0f\n\x07lotSize\x18\x02 \x01(\r\x12\x16\n\x0eorderSellPrice\x18\x03 \x01(\x01\x12\x15\n\rorderBuyPrice\x18\x04 \x01(\x01\"C\n\x08TickList\x12\x0e\n\x06market\x18\x01 \x01(\r\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x19\n\x04tick\x18\x03 \x03(\x0b\x32\x0b.Stock.Tick\"\xf3\x01\n\x04Tick\x12\x0e\n\x06req_id\x18\x01 \x01(\r\x12\x0b\n\x03now\x18\x02 \x01(\x01\x12\x12\n\ncur_volume\x18\x03 \x01(\r\x12\x11\n\ttick_flag\x18\x04 \x01(\r\x12\x1f\n\x07tick_vi\x18\x05 \x01(\x0e\x32\x0e.Stock.Tick_VI\x12-\n\ttick_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\trecv_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0egrey_tick_time\x18\x08 \x01(\t\x12\x10\n\x08modifier\x18\t \x01(\t\"\xa6\x01\n\x0fOrderStallsList\x12\x0e\n\x06market\x18\x01 \x01(\r\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12(\n\x04time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12%\n\torderSell\x18\x04 \x03(\x0b\x32\x12.Stock.OrderStalls\x12$\n\x08orderBuy\x18\x05 \x03(\x0b\x32\x12.Stock.OrderStalls\"Q\n\x0bOrderStalls\x12\r\n\x05level\x18\x01 \x01(\r\x12\r\n\x05price\x18\x02 \x01(\x01\x12\x0e\n\x06volume\x18\x03 \x01(\x04\x12\x14\n\x0c\x62roker_count\x18\x04 \x01(\r\"\xc8\x01\n\nBrokerList\x12\x0e\n\x06market\x18\x01 \x01(\r\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12(\n\x04time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12!\n\nbrokerSell\x18\x04 \x03(\x0b\x32\r.Stock.Broker\x12 \n\tbrokerBuy\x18\x05 \x03(\x0b\x32\r.Stock.Broker\x12-\n\trecv_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"1\n\x06\x42roker\x12\x14\n\x0c\x62roker_level\x18\x01 \x01(\r\x12\x11\n\tbroker_id\x18\x02 \x03(\t\"Z\n\nClearStock\x12\x0e\n\x06market\x18\x01 \x01(\r\x12\x12\n\nclear_flag\x18\x02 \x01(\r\x12\x14\n\x0cstock_status\x18\x03 \x01(\r\x12\x12\n\nstock_time\x18\x04 \x01(\t*S\n\x07Tick_VI\x12\x10\n\x0cTick_VI_None\x10\x00\x12\x05\n\x01X\x10\x01\x12\x05\n\x01\x44\x10\x02\x12\x05\n\x01R\x10\x03\x12\x05\n\x01M\x10\x04\x12\x05\n\x01N\x10\x05\x12\x05\n\x01Y\x10\x06\x12\x05\n\x01P\x10\x07\x12\x05\n\x01U\x10\x08*\xb6\x02\n\nUpdateFlag\x12\x07\n\x03now\x10\x00\x12\x08\n\x04open\x10\x01\x12\x08\n\x04high\x10\x02\x12\x07\n\x03low\x10\x03\x12\n\n\x06volume\x10\x04\x12\n\n\x06\x61mount\x10\x05\x12\x0e\n\nlast_close\x10\x06\x12\x13\n\x0f\x63ur_trade_count\x10\x07\x12\x0b\n\x07lotSize\x10\x08\x12\x12\n\x0eorderSellPrice\x10\t\x12\x11\n\rorderBuyPrice\x10\n\x12\x11\n\rquantityRatio\x10\x0b\x12\t\n\x05\x63lose\x10\x0c\x12\n\n\x06tickVi\x10\r\x12\x11\n\rtradingStatus\x10\x0e\x12\x10\n\x0cpre5MinPrice\x10\x0f\x12\r\n\touterDisk\x10\x10\x12\r\n\tinnerDisk\x10\x11\x12\x11\n\rnasdaq_volume\x10\x12\x12\x11\n\rnasdaq_amount\x10\x13\x42.\n#com.kaisaglobal.proto.stock.release\x80\x01\x00\x88\x01\x01\x90\x01\x00\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,stock__comm__pb2.DESCRIPTOR,msg__comm__cust__pb2.DESCRIPTOR,])

_TICK_VI = _descriptor.EnumDescriptor(
  name='Tick_VI',
  full_name='Stock.Tick_VI',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Tick_VI_None', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='X', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='D', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='R', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='M', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='N', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Y', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='P', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='U', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1838,
  serialized_end=1921,
)
_sym_db.RegisterEnumDescriptor(_TICK_VI)

Tick_VI = enum_type_wrapper.EnumTypeWrapper(_TICK_VI)
_UPDATEFLAG = _descriptor.EnumDescriptor(
  name='UpdateFlag',
  full_name='Stock.UpdateFlag',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='now', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='open', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='high', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='low', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='volume', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='amount', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='last_close', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='cur_trade_count', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='lotSize', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='orderSellPrice', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='orderBuyPrice', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='quantityRatio', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='close', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='tickVi', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='tradingStatus', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='pre5MinPrice', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='outerDisk', index=16, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='innerDisk', index=17, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='nasdaq_volume', index=18, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='nasdaq_amount', index=19, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1924,
  serialized_end=2234,
)
_sym_db.RegisterEnumDescriptor(_UPDATEFLAG)

UpdateFlag = enum_type_wrapper.EnumTypeWrapper(_UPDATEFLAG)
Tick_VI_None = 0
X = 1
D = 2
R = 3
M = 4
N = 5
Y = 6
P = 7
U = 8
now = 0
open = 1
high = 2
low = 3
volume = 4
amount = 5
last_close = 6
cur_trade_count = 7
lotSize = 8
orderSellPrice = 9
orderBuyPrice = 10
quantityRatio = 11
close = 12
tickVi = 13
tradingStatus = 14
pre5MinPrice = 15
outerDisk = 16
innerDisk = 17
nasdaq_volume = 18
nasdaq_amount = 19



_RULE = _descriptor.Descriptor(
  name='Rule',
  full_name='Stock.Rule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stockCodes', full_name='Stock.Rule.stockCodes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fields', full_name='Stock.Rule.fields', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=99,
  serialized_end=159,
)


_STOCKCODE = _descriptor.Descriptor(
  name='StockCode',
  full_name='Stock.StockCode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='Stock.StockCode.code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market', full_name='Stock.StockCode.market', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='Stock.StockCode.language', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='types', full_name='Stock.StockCode.types', index=3,
      number=4, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=162,
  serialized_end=302,
)


_QUOTE = _descriptor.Descriptor(
  name='Quote',
  full_name='Stock.Quote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market', full_name='Stock.Quote.market', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='Stock.Quote.code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='now', full_name='Stock.Quote.now', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='open', full_name='Stock.Quote.open', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='high', full_name='Stock.Quote.high', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='low', full_name='Stock.Quote.low', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_close', full_name='Stock.Quote.last_close', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume', full_name='Stock.Quote.volume', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='Stock.Quote.amount', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_flag', full_name='Stock.Quote.update_flag', index=9,
      number=10, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote_time', full_name='Stock.Quote.quote_time', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='recv_time', full_name='Stock.Quote.recv_time', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grey_quote', full_name='Stock.Quote.grey_quote', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quantityRatio', full_name='Stock.Quote.quantityRatio', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='close', full_name='Stock.Quote.close', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tick_vi', full_name='Stock.Quote.tick_vi', index=15,
      number=16, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trading_status', full_name='Stock.Quote.trading_status', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modifier', full_name='Stock.Quote.modifier', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pre5MinPrice', full_name='Stock.Quote.pre5MinPrice', index=18,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='outerDisk', full_name='Stock.Quote.outerDisk', index=19,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='innerDisk', full_name='Stock.Quote.innerDisk', index=20,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nasdaq_volume', full_name='Stock.Quote.nasdaq_volume', index=21,
      number=22, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nasdaq_amount', full_name='Stock.Quote.nasdaq_amount', index=22,
      number=23, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=305,
  serialized_end=821,
)


_GREYQUOTE = _descriptor.Descriptor(
  name='GreyQuote',
  full_name='Stock.GreyQuote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cur_trade_count', full_name='Stock.GreyQuote.cur_trade_count', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lotSize', full_name='Stock.GreyQuote.lotSize', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orderSellPrice', full_name='Stock.GreyQuote.orderSellPrice', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orderBuyPrice', full_name='Stock.GreyQuote.orderBuyPrice', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=823,
  serialized_end=923,
)


_TICKLIST = _descriptor.Descriptor(
  name='TickList',
  full_name='Stock.TickList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market', full_name='Stock.TickList.market', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='Stock.TickList.code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tick', full_name='Stock.TickList.tick', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=925,
  serialized_end=992,
)


_TICK = _descriptor.Descriptor(
  name='Tick',
  full_name='Stock.Tick',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='req_id', full_name='Stock.Tick.req_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='now', full_name='Stock.Tick.now', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cur_volume', full_name='Stock.Tick.cur_volume', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tick_flag', full_name='Stock.Tick.tick_flag', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tick_vi', full_name='Stock.Tick.tick_vi', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tick_time', full_name='Stock.Tick.tick_time', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='recv_time', full_name='Stock.Tick.recv_time', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grey_tick_time', full_name='Stock.Tick.grey_tick_time', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modifier', full_name='Stock.Tick.modifier', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=995,
  serialized_end=1238,
)


_ORDERSTALLSLIST = _descriptor.Descriptor(
  name='OrderStallsList',
  full_name='Stock.OrderStallsList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market', full_name='Stock.OrderStallsList.market', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='Stock.OrderStallsList.code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='Stock.OrderStallsList.time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orderSell', full_name='Stock.OrderStallsList.orderSell', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orderBuy', full_name='Stock.OrderStallsList.orderBuy', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1241,
  serialized_end=1407,
)


_ORDERSTALLS = _descriptor.Descriptor(
  name='OrderStalls',
  full_name='Stock.OrderStalls',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='level', full_name='Stock.OrderStalls.level', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='Stock.OrderStalls.price', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume', full_name='Stock.OrderStalls.volume', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='broker_count', full_name='Stock.OrderStalls.broker_count', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1409,
  serialized_end=1490,
)


_BROKERLIST = _descriptor.Descriptor(
  name='BrokerList',
  full_name='Stock.BrokerList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market', full_name='Stock.BrokerList.market', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='Stock.BrokerList.code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='Stock.BrokerList.time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brokerSell', full_name='Stock.BrokerList.brokerSell', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brokerBuy', full_name='Stock.BrokerList.brokerBuy', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='recv_time', full_name='Stock.BrokerList.recv_time', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1493,
  serialized_end=1693,
)


_BROKER = _descriptor.Descriptor(
  name='Broker',
  full_name='Stock.Broker',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broker_level', full_name='Stock.Broker.broker_level', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='broker_id', full_name='Stock.Broker.broker_id', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1695,
  serialized_end=1744,
)


_CLEARSTOCK = _descriptor.Descriptor(
  name='ClearStock',
  full_name='Stock.ClearStock',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market', full_name='Stock.ClearStock.market', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_flag', full_name='Stock.ClearStock.clear_flag', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stock_status', full_name='Stock.ClearStock.stock_status', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stock_time', full_name='Stock.ClearStock.stock_time', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1746,
  serialized_end=1836,
)

_RULE.fields_by_name['stockCodes'].message_type = _STOCKCODE
_STOCKCODE.fields_by_name['market'].enum_type = stock__comm__pb2._MARKET
_STOCKCODE.fields_by_name['language'].enum_type = stock__comm__pb2._LANGUAGE
_STOCKCODE.fields_by_name['types'].enum_type = stock__comm__pb2._SUBTYPE
_QUOTE.fields_by_name['quote_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_QUOTE.fields_by_name['recv_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_QUOTE.fields_by_name['grey_quote'].message_type = _GREYQUOTE
_QUOTE.fields_by_name['tick_vi'].enum_type = _TICK_VI
_TICKLIST.fields_by_name['tick'].message_type = _TICK
_TICK.fields_by_name['tick_vi'].enum_type = _TICK_VI
_TICK.fields_by_name['tick_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TICK.fields_by_name['recv_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ORDERSTALLSLIST.fields_by_name['time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ORDERSTALLSLIST.fields_by_name['orderSell'].message_type = _ORDERSTALLS
_ORDERSTALLSLIST.fields_by_name['orderBuy'].message_type = _ORDERSTALLS
_BROKERLIST.fields_by_name['time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_BROKERLIST.fields_by_name['brokerSell'].message_type = _BROKER
_BROKERLIST.fields_by_name['brokerBuy'].message_type = _BROKER
_BROKERLIST.fields_by_name['recv_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['Rule'] = _RULE
DESCRIPTOR.message_types_by_name['StockCode'] = _STOCKCODE
DESCRIPTOR.message_types_by_name['Quote'] = _QUOTE
DESCRIPTOR.message_types_by_name['GreyQuote'] = _GREYQUOTE
DESCRIPTOR.message_types_by_name['TickList'] = _TICKLIST
DESCRIPTOR.message_types_by_name['Tick'] = _TICK
DESCRIPTOR.message_types_by_name['OrderStallsList'] = _ORDERSTALLSLIST
DESCRIPTOR.message_types_by_name['OrderStalls'] = _ORDERSTALLS
DESCRIPTOR.message_types_by_name['BrokerList'] = _BROKERLIST
DESCRIPTOR.message_types_by_name['Broker'] = _BROKER
DESCRIPTOR.message_types_by_name['ClearStock'] = _CLEARSTOCK
DESCRIPTOR.enum_types_by_name['Tick_VI'] = _TICK_VI
DESCRIPTOR.enum_types_by_name['UpdateFlag'] = _UPDATEFLAG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Rule = _reflection.GeneratedProtocolMessageType('Rule', (_message.Message,), {
  'DESCRIPTOR' : _RULE,
  '__module__' : 'stock_real_pb2'
  # @@protoc_insertion_point(class_scope:Stock.Rule)
  })
_sym_db.RegisterMessage(Rule)

StockCode = _reflection.GeneratedProtocolMessageType('StockCode', (_message.Message,), {
  'DESCRIPTOR' : _STOCKCODE,
  '__module__' : 'stock_real_pb2'
  # @@protoc_insertion_point(class_scope:Stock.StockCode)
  })
_sym_db.RegisterMessage(StockCode)

Quote = _reflection.GeneratedProtocolMessageType('Quote', (_message.Message,), {
  'DESCRIPTOR' : _QUOTE,
  '__module__' : 'stock_real_pb2'
  # @@protoc_insertion_point(class_scope:Stock.Quote)
  })
_sym_db.RegisterMessage(Quote)

GreyQuote = _reflection.GeneratedProtocolMessageType('GreyQuote', (_message.Message,), {
  'DESCRIPTOR' : _GREYQUOTE,
  '__module__' : 'stock_real_pb2'
  # @@protoc_insertion_point(class_scope:Stock.GreyQuote)
  })
_sym_db.RegisterMessage(GreyQuote)

TickList = _reflection.GeneratedProtocolMessageType('TickList', (_message.Message,), {
  'DESCRIPTOR' : _TICKLIST,
  '__module__' : 'stock_real_pb2'
  # @@protoc_insertion_point(class_scope:Stock.TickList)
  })
_sym_db.RegisterMessage(TickList)

Tick = _reflection.GeneratedProtocolMessageType('Tick', (_message.Message,), {
  'DESCRIPTOR' : _TICK,
  '__module__' : 'stock_real_pb2'
  # @@protoc_insertion_point(class_scope:Stock.Tick)
  })
_sym_db.RegisterMessage(Tick)

OrderStallsList = _reflection.GeneratedProtocolMessageType('OrderStallsList', (_message.Message,), {
  'DESCRIPTOR' : _ORDERSTALLSLIST,
  '__module__' : 'stock_real_pb2'
  # @@protoc_insertion_point(class_scope:Stock.OrderStallsList)
  })
_sym_db.RegisterMessage(OrderStallsList)

OrderStalls = _reflection.GeneratedProtocolMessageType('OrderStalls', (_message.Message,), {
  'DESCRIPTOR' : _ORDERSTALLS,
  '__module__' : 'stock_real_pb2'
  # @@protoc_insertion_point(class_scope:Stock.OrderStalls)
  })
_sym_db.RegisterMessage(OrderStalls)

BrokerList = _reflection.GeneratedProtocolMessageType('BrokerList', (_message.Message,), {
  'DESCRIPTOR' : _BROKERLIST,
  '__module__' : 'stock_real_pb2'
  # @@protoc_insertion_point(class_scope:Stock.BrokerList)
  })
_sym_db.RegisterMessage(BrokerList)

Broker = _reflection.GeneratedProtocolMessageType('Broker', (_message.Message,), {
  'DESCRIPTOR' : _BROKER,
  '__module__' : 'stock_real_pb2'
  # @@protoc_insertion_point(class_scope:Stock.Broker)
  })
_sym_db.RegisterMessage(Broker)

ClearStock = _reflection.GeneratedProtocolMessageType('ClearStock', (_message.Message,), {
  'DESCRIPTOR' : _CLEARSTOCK,
  '__module__' : 'stock_real_pb2'
  # @@protoc_insertion_point(class_scope:Stock.ClearStock)
  })
_sym_db.RegisterMessage(ClearStock)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
