# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stock_comm.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='stock_comm.proto',
  package='StockCommon',
  syntax='proto3',
  serialized_options=b'\n#com.kaisaglobal.proto.stock.release\200\001\000\210\001\001\220\001\000',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x10stock_comm.proto\x12\x0bStockCommon\"\xce\x01\n\x05Login\x12\r\n\x05token\x18\x01 \x01(\t\x12\x10\n\x08\x64\x65viceId\x18\x02 \x01(\t\x12\x12\n\nmacAddress\x18\x03 \x01(\t\x12\x11\n\tipAddress\x18\x04 \x01(\t\x12\x12\n\nsysVersion\x18\x05 \x01(\t\x12\x10\n\x08platform\x18\x06 \x01(\t\x12\x12\n\nphoneModel\x18\x07 \x01(\t\x12\x0f\n\x07srvType\x18\x08 \x01(\t\x12\x10\n\x08username\x18\t \x01(\t\x12\x10\n\x08password\x18\n \x01(\t\x12\x0e\n\x06userId\x18\x0b \x01(\t*\xa8\x01\n\x03Mod\x12\x0c\n\x08MOD_NONE\x10\x00\x12\x07\n\x03SUB\x10\x01\x12\x0e\n\nHEART_BEAT\x10\x03\x12\t\n\x05LOGIN\x10\x14\x12\x0c\n\x08HANDICAP\x10\x04\x12\t\n\x05PLATE\x10\x05\x12\r\n\tASSETINFO\x10\x06\x12\r\n\tTRANS_STA\x10\x07\x12\x0c\n\x08\x44\x41TA_DIC\x10\x08\x12\x10\n\x0cQUANT_FACTOR\x10\t\x12\n\n\x06\x41\x43TION\x10\x64\x12\x0c\n\x07RAM_MOD\x10\xc8\x01*H\n\x07SubType\x12\x11\n\rSUB_TYPE_NONE\x10\x00\x12\t\n\x05QUOTE\x10\x01\x12\x08\n\x04TICK\x10\x02\x12\n\n\x06\x42ROKER\x10\x03\x12\t\n\x05ORDER\x10\x04*\xa9\x04\n\x03\x43md\x12\x0c\n\x08\x43MD_NONE\x10\x00\x12\x0c\n\x08SubQuote\x10\n\x12\x0e\n\nUnSubQuote\x10\x0b\x12\x11\n\rHandicapQuota\x10\x15\x12\t\n\x05Kline\x10\x16\x12\x0c\n\x08TickInfo\x10\x17\x12\x0f\n\x0bMinuteQuote\x10\x18\x12\x0f\n\x0b\x42uySellList\x10\x19\x12\x0e\n\nBrokerInfo\x10\x1a\x12\x10\n\x0cHistoryKline\x10\x1b\x12\x13\n\x0fHistoryTickInfo\x10\x1c\x12\x13\n\x0fPopularIndustry\x10\x64\x12\x12\n\x0ePopularConcept\x10\x65\x12\x12\n\x0e\x41llSectorQuota\x10\x66\x12\x11\n\rIndustryQuota\x10g\x12\x10\n\x0c\x43onceptQuota\x10h\x12\x0e\n\nIndexQuota\x10i\x12\x14\n\x10IndexConstituent\x10j\x12\x13\n\x0fNewSharesListed\x10k\x12\x0b\n\x07Warrant\x10l\x12\x0b\n\x07\x41hStock\x10m\x12\x14\n\x10WarrantAssetInfo\x10n\x12\x13\n\x0e\x42\x61sicAssetInfo\x10\xc8\x01\x12\x17\n\x12\x42\x61sicSubMarketInfo\x10\xc9\x01\x12\x18\n\x13\x41ssetInfoByCodeList\x10\xca\x01\x12\x14\n\x0fTransactionStat\x10\xac\x02\x12\x0c\n\x07\x44icData\x10\x90\x03\x12\x14\n\x0fSTOCK_BACK_TEST\x10\x85\x07\x12\x0f\n\nClearStock\x10\xf4\x03\x12\x11\n\x0c\x45xchangeRate\x10\xf5\x03*\x9b\x01\n\x04\x43ode\x12\x0b\n\x07SUCCESS\x10\x00\x12\x0e\n\nNO_INVOKER\x10\x01\x12\x12\n\x0e\x41GRUMENT_ERROR\x10\x02\x12\x14\n\x10UNKOWN_EXCEPTION\x10\x03\x12\x12\n\x0ePASSWARD_ERROR\x10\x04\x12\r\n\tHAS_LOGIN\x10\x05\x12\x0e\n\nLOGIN_FAIL\x10\x06\x12\x0c\n\x08NO_LOGIN\x10\x07\x12\x0b\n\x07TIMEOUT\x10\x08*j\n\x06Market\x12\x08\n\x04NONE\x10\x00\x12\x06\n\x02\x43N\x10\x01\x12\x06\n\x02HK\x10\x02\x12\x06\n\x02US\x10\x03\x12\x06\n\x02QS\x10\x1e\x12\x06\n\x02NS\x10\x1f\x12\x06\n\x02\x41S\x10 \x12\x06\n\x02PS\x10!\x12\x06\n\x02\x42S\x10\"\x12\x06\n\x02VS\x10#\x12\x06\n\x02SH\x10\n\x12\x06\n\x02SZ\x10\x0b*\"\n\x08Language\x12\x06\n\x02ZH\x10\x00\x12\x06\n\x02TW\x10\x01\x12\x06\n\x02\x45N\x10\x02*\xb9\x01\n\tQuoteType\x12\x08\n\x04NULL\x10\x00\x12\x08\n\x04MIN1\x10\x01\x12\x08\n\x04MIN3\x10\x02\x12\x08\n\x04MIN5\x10\x03\x12\t\n\x05MIN10\x10\x04\x12\t\n\x05MIN15\x10\x05\x12\t\n\x05MIN30\x10\x06\x12\t\n\x05HOUR1\x10\x07\x12\t\n\x05HOUR2\x10\x08\x12\t\n\x05HOUR4\x10\t\x12\x08\n\x04\x44\x41Y1\x10\n\x12\x08\n\x04\x44\x41Y5\x10\x0b\x12\t\n\x05WEEK1\x10\x0c\x12\n\n\x06MONTH1\x10\r\x12\x0c\n\x08QUARTER1\x10\x0e\x12\t\n\x05YEAR1\x10\x0f\x42.\n#com.kaisaglobal.proto.stock.release\x80\x01\x00\x88\x01\x01\x90\x01\x00\x62\x06proto3'
)

_MOD = _descriptor.EnumDescriptor(
  name='Mod',
  full_name='StockCommon.Mod',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MOD_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SUB', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HEART_BEAT', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOGIN', index=3, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HANDICAP', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PLATE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ASSETINFO', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRANS_STA', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATA_DIC', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='QUANT_FACTOR', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTION', index=10, number=100,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RAM_MOD', index=11, number=200,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=243,
  serialized_end=411,
)
_sym_db.RegisterEnumDescriptor(_MOD)

Mod = enum_type_wrapper.EnumTypeWrapper(_MOD)
_SUBTYPE = _descriptor.EnumDescriptor(
  name='SubType',
  full_name='StockCommon.SubType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUB_TYPE_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='QUOTE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TICK', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BROKER', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ORDER', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=413,
  serialized_end=485,
)
_sym_db.RegisterEnumDescriptor(_SUBTYPE)

SubType = enum_type_wrapper.EnumTypeWrapper(_SUBTYPE)
_CMD = _descriptor.EnumDescriptor(
  name='Cmd',
  full_name='StockCommon.Cmd',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CMD_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SubQuote', index=1, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UnSubQuote', index=2, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HandicapQuota', index=3, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Kline', index=4, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TickInfo', index=5, number=23,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MinuteQuote', index=6, number=24,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BuySellList', index=7, number=25,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BrokerInfo', index=8, number=26,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HistoryKline', index=9, number=27,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HistoryTickInfo', index=10, number=28,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PopularIndustry', index=11, number=100,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PopularConcept', index=12, number=101,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AllSectorQuota', index=13, number=102,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IndustryQuota', index=14, number=103,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ConceptQuota', index=15, number=104,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IndexQuota', index=16, number=105,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IndexConstituent', index=17, number=106,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NewSharesListed', index=18, number=107,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Warrant', index=19, number=108,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AhStock', index=20, number=109,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WarrantAssetInfo', index=21, number=110,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BasicAssetInfo', index=22, number=200,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BasicSubMarketInfo', index=23, number=201,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AssetInfoByCodeList', index=24, number=202,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TransactionStat', index=25, number=300,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DicData', index=26, number=400,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOCK_BACK_TEST', index=27, number=901,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ClearStock', index=28, number=500,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ExchangeRate', index=29, number=501,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=488,
  serialized_end=1041,
)
_sym_db.RegisterEnumDescriptor(_CMD)

Cmd = enum_type_wrapper.EnumTypeWrapper(_CMD)
_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='StockCommon.Code',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_INVOKER', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AGRUMENT_ERROR', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNKOWN_EXCEPTION', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PASSWARD_ERROR', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HAS_LOGIN', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOGIN_FAIL', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_LOGIN', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TIMEOUT', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1044,
  serialized_end=1199,
)
_sym_db.RegisterEnumDescriptor(_CODE)

Code = enum_type_wrapper.EnumTypeWrapper(_CODE)
_MARKET = _descriptor.EnumDescriptor(
  name='Market',
  full_name='StockCommon.Market',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HK', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='US', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='QS', index=4, number=30,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NS', index=5, number=31,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AS', index=6, number=32,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PS', index=7, number=33,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BS', index=8, number=34,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VS', index=9, number=35,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SH', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SZ', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1201,
  serialized_end=1307,
)
_sym_db.RegisterEnumDescriptor(_MARKET)

Market = enum_type_wrapper.EnumTypeWrapper(_MARKET)
_LANGUAGE = _descriptor.EnumDescriptor(
  name='Language',
  full_name='StockCommon.Language',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ZH', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TW', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1309,
  serialized_end=1343,
)
_sym_db.RegisterEnumDescriptor(_LANGUAGE)

Language = enum_type_wrapper.EnumTypeWrapper(_LANGUAGE)
_QUOTETYPE = _descriptor.EnumDescriptor(
  name='QuoteType',
  full_name='StockCommon.QuoteType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NULL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MIN1', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MIN3', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MIN5', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MIN10', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MIN15', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MIN30', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HOUR1', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HOUR2', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HOUR4', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DAY1', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DAY5', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WEEK1', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MONTH1', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='QUARTER1', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='YEAR1', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1346,
  serialized_end=1531,
)
_sym_db.RegisterEnumDescriptor(_QUOTETYPE)

QuoteType = enum_type_wrapper.EnumTypeWrapper(_QUOTETYPE)
MOD_NONE = 0
SUB = 1
HEART_BEAT = 3
LOGIN = 20
HANDICAP = 4
PLATE = 5
ASSETINFO = 6
TRANS_STA = 7
DATA_DIC = 8
QUANT_FACTOR = 9
ACTION = 100
RAM_MOD = 200
SUB_TYPE_NONE = 0
QUOTE = 1
TICK = 2
BROKER = 3
ORDER = 4
CMD_NONE = 0
SubQuote = 10
UnSubQuote = 11
HandicapQuota = 21
Kline = 22
TickInfo = 23
MinuteQuote = 24
BuySellList = 25
BrokerInfo = 26
HistoryKline = 27
HistoryTickInfo = 28
PopularIndustry = 100
PopularConcept = 101
AllSectorQuota = 102
IndustryQuota = 103
ConceptQuota = 104
IndexQuota = 105
IndexConstituent = 106
NewSharesListed = 107
Warrant = 108
AhStock = 109
WarrantAssetInfo = 110
BasicAssetInfo = 200
BasicSubMarketInfo = 201
AssetInfoByCodeList = 202
TransactionStat = 300
DicData = 400
STOCK_BACK_TEST = 901
ClearStock = 500
ExchangeRate = 501
SUCCESS = 0
NO_INVOKER = 1
AGRUMENT_ERROR = 2
UNKOWN_EXCEPTION = 3
PASSWARD_ERROR = 4
HAS_LOGIN = 5
LOGIN_FAIL = 6
NO_LOGIN = 7
TIMEOUT = 8
NONE = 0
CN = 1
HK = 2
US = 3
QS = 30
NS = 31
AS = 32
PS = 33
BS = 34
VS = 35
SH = 10
SZ = 11
ZH = 0
TW = 1
EN = 2
NULL = 0
MIN1 = 1
MIN3 = 2
MIN5 = 3
MIN10 = 4
MIN15 = 5
MIN30 = 6
HOUR1 = 7
HOUR2 = 8
HOUR4 = 9
DAY1 = 10
DAY5 = 11
WEEK1 = 12
MONTH1 = 13
QUARTER1 = 14
YEAR1 = 15



_LOGIN = _descriptor.Descriptor(
  name='Login',
  full_name='StockCommon.Login',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='StockCommon.Login.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deviceId', full_name='StockCommon.Login.deviceId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='macAddress', full_name='StockCommon.Login.macAddress', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipAddress', full_name='StockCommon.Login.ipAddress', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sysVersion', full_name='StockCommon.Login.sysVersion', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='platform', full_name='StockCommon.Login.platform', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='phoneModel', full_name='StockCommon.Login.phoneModel', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='srvType', full_name='StockCommon.Login.srvType', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='username', full_name='StockCommon.Login.username', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='StockCommon.Login.password', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='userId', full_name='StockCommon.Login.userId', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=34,
  serialized_end=240,
)

DESCRIPTOR.message_types_by_name['Login'] = _LOGIN
DESCRIPTOR.enum_types_by_name['Mod'] = _MOD
DESCRIPTOR.enum_types_by_name['SubType'] = _SUBTYPE
DESCRIPTOR.enum_types_by_name['Cmd'] = _CMD
DESCRIPTOR.enum_types_by_name['Code'] = _CODE
DESCRIPTOR.enum_types_by_name['Market'] = _MARKET
DESCRIPTOR.enum_types_by_name['Language'] = _LANGUAGE
DESCRIPTOR.enum_types_by_name['QuoteType'] = _QUOTETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Login = _reflection.GeneratedProtocolMessageType('Login', (_message.Message,), {
  'DESCRIPTOR' : _LOGIN,
  '__module__' : 'stock_comm_pb2'
  # @@protoc_insertion_point(class_scope:StockCommon.Login)
  })
_sym_db.RegisterMessage(Login)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
